@@ -1,9 +1,10 @@
 # coding: utf8
+from __future__ import division
 import os, time, numbers, math, io, warnings, sys
 import pygame
 import requests
 import cache
-from .utils import cached_property
+from .utils import cached_property, get_resource
 
 # colors from http://clrs.cc/
 color_map = {
@@ -27,7 +28,7 @@ color_map = {
     'black': (0, 0, 0),
 }
 
-broken_image_file = os.path.join(os.path.dirname(__file__), 'broken_image.png')
+broken_image_file = get_resource('broken_image.png')
 
 def _xy_add(t1, t2):
     return (t1[0] + t2[0], t1[1] + t2[1])
@@ -89,7 +90,7 @@ def _scale(scale):
 def _font(font, font_size, antialias):
     pygame.font.init()
     if font is None:
-        font = os.path.join(os.path.dirname(__file__), 'Geneva.ttf')
+        font = get_resource('Geneva.ttf')
         if antialias is None:
             antialias = (font_size < 9 or 17 < font_size)
 
@@ -147,6 +148,14 @@ class Surface(object):
     def size(self):
         return self.surface.get_size()
 
+    @property
+    def width(self):
+        return self.size[0]
+
+    @property
+    def height(self):
+        return self.size[1]
+
     def _fill(self, color, rect=None):
         if len(color) <= 3:
             self.surface.fill(color, rect)
@@ -161,9 +170,9 @@ class Surface(object):
     def text(self, string, xy=None, color='grey', align='center', font=None, font_size=32, antialias=None, max_width=sys.maxsize, max_height=sys.maxsize, max_lines=sys.maxsize):
         if xy is None:
             if max_width == sys.maxsize:
-                max_width = 320
+                max_width = self.width
             if max_height == sys.maxsize:
-                max_height = 240
+                max_height = self.height
 
         text_image = Image.from_text(
             string,
@@ -176,7 +185,7 @@ class Surface(object):
             max_height=max_height,
             align=_anchor(align)[0])
 
-        self.image(text_image, xy, align=align)
+        self.image(text_image, xy=xy, align=align, scale=1)
 
     def rectangle(self, xy=None, size=(100, 100), color='grey', align='center'):
         if len(size) != 2:
@@ -215,7 +224,7 @@ class Surface(object):
 
             pygame.draw.polygon(self.surface, _color(color), points)
 
-    def image(self, image, xy=None, scale=1, alpha=1.0, align='center', raise_error=True):
+    def image(self, image, xy=None, scale='shrinkToFit', alpha=1.0, align='center', max_width=sys.maxsize, max_height=sys.maxsize, raise_error=True):
         if isinstance(image, basestring):
             try:
                 image = image_cache.get_image(image)
@@ -225,8 +234,6 @@ class Surface(object):
                 else:
                     image = image_cache.get_image(broken_image_file)
 
-        scale = _scale(scale)
-
         if hasattr(image, 'surface'):
             image_size = image.size
             surface = image.surface
@@ -235,6 +242,27 @@ class Surface(object):
             surface = image
             image_size = surface.get_size()
 
+        if scale in ('fit', 'fill', 'shrinkToFit'):
+            if max_width == sys.maxsize:
+                max_width = self.width
+            if max_height == sys.maxsize:
+                max_height = self.height
+
+            fit_scale = min(max_width / image_size[0], max_height / image_size[1])
+            fill_scale = max(max_width / image_size[0], max_height / image_size[1])
+
+            if scale == 'shrinkToFit':
+                if fit_scale < 1:
+                    scale = fit_scale
+                else:
+                    scale = 1
+            elif scale == 'fit':
+                scale = fit_scale
+            elif scale == 'fill':
+                scale = fill_scale
+
+        scale = _scale(scale)
+
         # blit_surface is a temporary variable to minimise copying on each tranformation
         blit_surface = surface
 
@@ -324,10 +352,6 @@ screen = Screen()
 class Image(Surface):
     @classmethod
     def load(cls, filename):
-        warnings.warn(
-            'Image.load is deprecated. Use Image.load_filename instead.',
-            DeprecationWarning,
-            stacklevel=2)
         return cls.load_filename(filename)
 
     @classmethod
@@ -372,7 +396,13 @@ class Image(Surface):
 
         if max_height != sys.maxsize:
             line_height = font.get_linesize()
-            max_lines = min(max_lines, int(max_height/line_height))
+            max_lines_by_height = int(max_height//line_height)
+
+            if max_lines_by_height < 1:
+                # never collapse the text to zero lines because of the height restriction
+                max_lines_by_height = 1
+
+            max_lines = min(max_lines, max_lines_by_height)
 
         surface = render_text(string, font, antialias, color, max_lines, max_width, ellipsis=u'…', align=align)
 
@@ -380,7 +410,7 @@ class Image(Surface):
 
     def __init__(self, surface=None, size=None):
         pygame.init()
-        surface = surface or pygame.Surface(size)
+        surface = surface or pygame.Surface(size, flags=pygame.SRCALPHA)
         super(Image, self).__init__(surface)
 
     def get_memory_usage(self):
